==> cognite_power_ops-0.96.2-py3-none-any.whl: cognite/powerops/client/_generated/v1/_api/benchmarking_task_dispatcher_input_day_ahead_query.py <==
from __future__ import annotations

import datetime
from typing import TYPE_CHECKING

from cognite.client import data_modeling as dm, CogniteClient

from cognite.powerops.client._generated.v1.data_classes import (
    DomainModelCore,
    BenchmarkingTaskDispatcherInputDayAhead,
    BenchmarkingConfigurationDayAhead,
)
from ._core import DEFAULT_QUERY_LIMIT, QueryBuilder, QueryStep, QueryAPI, T_DomainModelList, _create_edge_filter


class BenchmarkingTaskDispatcherInputDayAheadQueryAPI(QueryAPI[T_DomainModelList]):
    def __init__(
        self,
        client: CogniteClient,
        builder: QueryBuilder[T_DomainModelList],
        view_by_read_class: dict[type[DomainModelCore], dm.ViewId],
        filter_: dm.filters.Filter | None = None,
        limit: int = DEFAULT_QUERY_LIMIT,
    ):
        super().__init__(client, builder, view_by_read_class)

        self._builder.append(
            QueryStep(
                name=self._builder.next_name("benchmarking_task_dispatcher_input_day_ahead"),
                expression=dm.query.NodeResultSetExpression(
                    from_=self._builder[-1].name if self._builder else None,
                    filter=filter_,
                ),
                select=dm.query.Select(
                    [dm.query.SourceSelector(self._view_by_read_class[BenchmarkingTaskDispatcherInputDayAhead], ["*"])]
                ),
                result_cls=BenchmarkingTaskDispatcherInputDayAhead,
                max_retrieve_limit=limit,
            )
        )

    def query(
        self,
        retrieve_benchmarking_config: bool = False,
    ) -> T_DomainModelList:
        """Execute query and return the result.

        Args:
            retrieve_benchmarking_config: Whether to retrieve the benchmarking config for each benchmarking task dispatcher input day ahead or not.

        Returns:
            The list of the source nodes of the query.

        """
        from_ = self._builder[-1].name
        if retrieve_benchmarking_config:
            self._query_append_benchmarking_config(from_)
        return self._query()

    def _query_append_benchmarking_config(self, from_: str) -> None:
        view_id = self._view_by_read_class[BenchmarkingConfigurationDayAhead]
        self._builder.append(
            QueryStep(
                name=self._builder.next_name("benchmarking_config"),
                expression=dm.query.NodeResultSetExpression(
                    filter=dm.filters.HasData(views=[view_id]),
                    from_=from_,
                    through=self._view_by_read_class[BenchmarkingTaskDispatcherInputDayAhead].as_property_ref(
                        "benchmarkingConfig"
                    ),
                    direction="outwards",
                ),
                select=dm.query.Select([dm.query.SourceSelector(view_id, ["*"])]),
                max_retrieve_limit=-1,
                result_cls=BenchmarkingConfigurationDayAhead,
                is_single_direct_relation=True,
            ),
        )

==> cognite_power_ops-0.108.0-py3-none-any.whl: cognite/powerops/client/_generated/v1/_api/benchmarking_task_dispatcher_input_day_ahead_query.py <==
from __future__ import annotations

import datetime
from collections.abc import Sequence
from typing import TYPE_CHECKING, cast

from cognite.client import data_modeling as dm, CogniteClient

from cognite.powerops.client._generated.v1.data_classes import (
    DomainModelCore,
    BenchmarkingTaskDispatcherInputDayAhead,
    BenchmarkingConfigurationDayAhead,
)
from cognite.powerops.client._generated.v1._api._core import (
    DEFAULT_QUERY_LIMIT,
    EdgeQueryStep,
    NodeQueryStep,
    DataClassQueryBuilder,
    QueryAPI,
    T_DomainModelList,
    _create_edge_filter,
)



class BenchmarkingTaskDispatcherInputDayAheadQueryAPI(QueryAPI[T_DomainModelList]):
    _view_id = dm.ViewId("power_ops_core", "BenchmarkingTaskDispatcherInputDayAhead", "1")

    def __init__(
        self,
        client: CogniteClient,
        builder: DataClassQueryBuilder[T_DomainModelList],
        filter_: dm.filters.Filter | None = None,
        limit: int = DEFAULT_QUERY_LIMIT,
    ):
        super().__init__(client, builder)
        from_ = self._builder.get_from()
        self._builder.append(
            NodeQueryStep(
                name=self._builder.create_name(from_),
                expression=dm.query.NodeResultSetExpression(
                    from_=from_,
                    filter=filter_,
                ),
                result_cls=BenchmarkingTaskDispatcherInputDayAhead,
                max_retrieve_limit=limit,
            )
        )

    def query(
        self,
        retrieve_benchmarking_config: bool = False,
    ) -> T_DomainModelList:
        """Execute query and return the result.

        Args:
            retrieve_benchmarking_config: Whether to retrieve the benchmarking config for each benchmarking task dispatcher input day ahead or not.

        Returns:
            The list of the source nodes of the query.

        """
        from_ = self._builder[-1].name
        if retrieve_benchmarking_config:
            self._query_append_benchmarking_config(from_)
        return self._query()

    def _query_append_benchmarking_config(self, from_: str) -> None:
        self._builder.append(
            NodeQueryStep(
                name=self._builder.create_name(from_),
                expression=dm.query.NodeResultSetExpression(
                    from_=from_,
                    through=self._view_id.as_property_ref("benchmarkingConfig"),
                    direction="outwards",
                    filter=dm.filters.HasData(views=[BenchmarkingConfigurationDayAhead._view_id]),
                ),
                result_cls=BenchmarkingConfigurationDayAhead,
            ),
        )
